<?php

/**
 * This file is part of the SOLURIS - RGPD Management application.
 *
 * (c) Donovan Bourlard <donovan.bourlard@outlook.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace App\Tests\Domain\Registry\Form\Type;

use App\Domain\Registry\Form\Type\MesurementType;
use App\Domain\Registry\Model\Mesurement;
use App\Tests\Utils\FormTypeHelper;
use Knp\DictionaryBundle\Form\Type\DictionaryType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\OptionsResolver\OptionsResolver;

class MesurementTypeTest extends FormTypeHelper
{
    public function testInstanceOf()
    {
        $this->assertInstanceOf(AbstractType::class, new MesurementType());
    }

    public function testBuildForm()
    {
        $builder = [
            'name'              => TextType::class,
            'description'       => TextareaType::class,
            'cost'              => TextType::class,
            'charge'            => TextType::class,
            'status'            => DictionaryType::class,
            'planificationDate' => DateType::class,
            'comment'           => TextType::class,
        ];

        (new MesurementType())->buildForm($this->prophesizeBuilder($builder), []);
    }

    public function testConfigureOptions(): void
    {
        $defaults = [
            'data_class'        => Mesurement::class,
            'validation_groups' => [
                'default',
                'mesurement',
            ],
        ];

        $resolverProphecy = $this->prophesize(OptionsResolver::class);
        $resolverProphecy->setDefaults($defaults)->shouldBeCalled();

        (new MesurementType())->configureOptions($resolverProphecy->reveal());
    }
}
